# ODSL Python SDK

The python SDK for the [OpenDataDSL](https://opendatadsl.com) data management platform

## Usage
Logging in and getting started

```python
from odsl import sdk

odsl = sdk.ODSL()
odsl.login()
```

